from distutils.core import setup
setup(
  name = 'scopeton',
  packages = ['scopeton'],
  version = '1.001',
  description = 'Dependency injection mechanism',
  author = 'Anatolii Yakushko',
  author_email = 'shaddyx@gmail.com',
  url = 'https://github.com/shaddyx/scopeton', # use the URL to the github repo
  download_url = 'https://github.com/shaddyx/scopeton/tarball/0.1',
  keywords = ['dependency', 'injection'], # arbitrary keywords
  classifiers = []
)
